@@ -2,21 +2,15 @@ from zope.interface import implements
 from zope.component import adapts
 from zope.i18nmessageid import MessageFactory
 
-#from archetypes.markerfield.field import InterfaceMarkerField
 from Products.Archetypes.public import StringField, BooleanField
 
 from Products.ATContentTypes.interfaces.news import IATNewsItem
 from Products.ATContentTypes.interface import IATFolder, IATTopic
 from Products.Archetypes.atapi import SelectionWidget, BooleanWidget
-
 from archetypes.schemaextender.interfaces import ISchemaExtender, IBrowserLayerAwareExtender 
 from archetypes.schemaextender.field import ExtensionField
-
 from medialog.newsitemview.interfaces import INewsitemObject, IFolderObject
 
-from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm
-#from medialog.newsitemview.vocabulary import ImageSizeVocabulary 
-
 
 _ = MessageFactory('medialog.newsitemview')
 
@@ -27,21 +21,18 @@ class _StringExtensionField (ExtensionField, StringField):
 class _BooleanExtensionField(ExtensionField, BooleanField):
 	pass    
 
-    
-# need to get vocabulary to work from vocabulary.py    
-
+ 
+ 
 
 class ContentTypeExtender(object):
     """Adapter that adds custom data used for news item image size."""
     adapts(IATNewsItem)
-    imagesises = ['thumb', 'mini', 'preview', 'large', 'none'] 
     implements(ISchemaExtender, IBrowserLayerAwareExtender)
     layer = INewsitemObject
     _fields = [
         _StringExtensionField("newsitemsize",
             schemata = "settings",
-            enforceVocabulary=True,
-            vocabulary = imagesises,
+            vocabulary_factory='medialog.newsitemview.ImageSizeVocabulary',
             default="preview",
             interfaces = (INewsitemObject,),
             widget = SelectionWidget(
@@ -59,21 +50,16 @@ class ContentTypeExtender(object):
     def getFields(self):
         return self._fields
 
-#    def __init__(self, contentType):
-#        pass
-
 class FolderTypeExtender(object):
     """Adapter that adds custom data used for image size."""
     adapts(IATFolder)
-    imagesises = ['thumb', 'mini', 'preview', 'large', 'none'] 
     implements(ISchemaExtender, IBrowserLayerAwareExtender)
     layer = IFolderObject
     _fields = [
         _StringExtensionField("folderimagesize",
             schemata = "settings",
-            enforceVocabulary=True,
-            vocabulary =  imagesises,
-            default="preview",
+            default="mini",
+            vocabulary_factory='medialog.newsitemview.ImageSizeVocabulary',
             interfaces = (INewsitemObject,),
             widget = SelectionWidget(
                 label = _(u"label_folderimagesize",
@@ -102,22 +88,17 @@ class FolderTypeExtender(object):
     def getFields(self):
         return self._fields
 
-#    def __init__(self, contentType):
-#        pass
-
 
 class TopicTypeExtender(object):
     """Adapter that adds custom data used for image size."""
     adapts(IATTopic)
-    imagesises = ['thumb', 'mini', 'preview', 'large', 'none'] 
     implements(ISchemaExtender, IBrowserLayerAwareExtender)
     layer = IFolderObject
     _fields = [
         _StringExtensionField("folderimagesize",
             schemata = "settings",
-            enforceVocabulary=True,
-            vocabulary = imagesises,
-            default="preview",
+            vocabulary_factory='medialog.newsitemview.ImageSizeVocabulary',
+            default="mini",
             interfaces = (INewsitemObject,),
             widget = SelectionWidget(
                 label = _(u"label_folderimagesize",
@@ -135,5 +116,3 @@ class TopicTypeExtender(object):
     def getFields(self):
         return self._fields
 
-#    def __init__(self, contentType):
-#        pass
\ No newline at end of file
